import serial
import requests

# 配置 Arduino 序列埠
serial_port = 'COM6'  # 根據你的 Arduino 連接埠調整
baud_rate = 115200  # 與 Arduino 設置一致

# Line Bot 配置
line_token = "I9J/JaWPp5QglnDO7Gf5gcGw+6/bPOA3ZefVHvTACTTaI+VcQHPqYBrVRBEJzyhKvm7vJxbGCG3neOoPuJBkjPAWrSptU+/aLXrrWOsU+c8Nc9Ibutv8bml88v7/kDCtaCUq6vlrDGVaNkBywzSntwdB04t89/1O/w1cDnyilFU="
line_url = "https://api.line.me/v2/bot/message/push"
line_user_id = "Uc9bd2886abac831913c7e962b965f841"

# 發送 Line 訊息的函式


def send_line_message(message):
    headers = {
        "Authorization": f"Bearer {line_token}",
        "Content-Type": "application/json"
    }
    payload = {
        "to": line_user_id,
        "messages": [
            {"type": "text", "text": message}
        ]
    }
    response = requests.post(line_url, json=payload, headers=headers)
    if response.status_code == 200:
        print("Line 訊息發送成功！")
    else:
        print(f"Line 訊息發送失敗，錯誤代碼: {response.status_code}, 訊息: {response.text}")


# 監聽 Arduino 並處理資料
try:
    ser = serial.Serial(serial_port, baud_rate, timeout=1)
    print("開始監聽 Arduino 資料...")

    while True:
        if ser.in_waiting > 0:
            # 從 Arduino 讀取一行資料並解碼
            line = ser.readline().decode('utf-8').strip()
            print(f"接收到 Arduino 訊息: {line}")

            # 假設資料格式為 "Temperature: 36.5"
            if "Temperature" in line:
                try:
                    # 提取溫度數值
                    temp_str = line.split(":")[1].strip()
                    temperature = float(temp_str)

                    # 溫度高於 35°C 時發送警告
                    if temperature > 35:
                        warning_message = f"警告！溫度過高: {temperature}°C"
                        send_line_message(warning_message)
                except ValueError:
                    print("無法解析溫度值，資料格式可能有誤！")

except KeyboardInterrupt:
    print("結束程式。")
    ser.close()
except serial.SerialException as e:
    print(f"無法開啟序列埠，錯誤: {e}")
